@@ -732,6 +732,7 @@ int wplip_unreg_tty(wplip_link_t *lip_link)
 {
 	struct serial_state * state;
 	unsigned long smp_flags;
+    int i;
 
 	DEBUG_TEST("%s: %s() cnt=%i\n",
 			lip_link->name,__FUNCTION__,tty_init_cnt);
@@ -746,6 +747,10 @@ int wplip_unreg_tty(wplip_link_t *lip_link)
 #ifndef LINUX_2_6
 		*serial_driver.refcount=0;
 #endif
+        for(i=0;i<(MAX_PORT+1);i++){
+			tty_unregister_device(&serial_driver,i);
+		}
+
 		if ((e1 = tty_unregister_driver(&serial_driver))){
 			DEBUG_EVENT( "SERIAL: failed to unregister serial driver (%d)\n",
 			       e1);
