@@ -1117,6 +1117,9 @@ static int wp_tdmv_software_init(wan_tdmv_t *wan_tdmv)
 	wp->span.close = wp_tdmv_close;
 	wp->span.channels = wp->max_timeslots;
 #ifdef DAHDI_ISSUES
+#ifdef DAHDI_23
+    wp->span.owner = THIS_MODULE;
+#endif
 	wp->span.chans = wp->chans_ptrs;
 #else
 	wp->span.chans = wp->chans;
