@@ -615,7 +615,8 @@ static int wp_tdmapi_open(struct inode *inode, struct file *file)
 	}
 	
 	file->private_data = tdm_api; 
-	
+	tdm_api->loop=0;
+
 	wan_spin_unlock(&tdm_api->lock);
 	wan_spin_unlock_irq(&wp_tdmapi_hash_lock,&flags);
 	
@@ -1515,6 +1516,14 @@ int wanpipe_tdm_api_ioctl(wanpipe_tdm_api_dev_t *tdm_api, struct ifreq *ifr)
 			usr_tdm_api.hw_dtmf = WANOPT_NO;
 		}
 		break;
+
+	case SIOC_WP_TDM_ENABLE_LOOP:
+		tdm_api->loop=1;
+		break;
+	
+	case SIOC_WP_TDM_DISABLE_LOOP:
+		tdm_api->loop=0;
+		break;
 		
 	case SIOC_WP_TDM_GET_STATS:
 		memcpy(&usr_tdm_api.stats,&tdm_api->cfg.stats,sizeof(tdm_api->cfg.stats));
@@ -2136,6 +2145,9 @@ int wanpipe_tdm_api_rx_tx (wanpipe_tdm_api_dev_t *tdm_api, u8 *rx_data, u8 *tx_d
 	wanpipe_tdm_api_rx (tdm_api, rx_data, tx_data, len);
 	wanpipe_tdm_api_tx (tdm_api, tx_data, len);
 
+	if (tdm_api->loop) {
+		memcpy(tx_data,rx_data,len);
+	}
 	
 	return 0;
 }
